@@ -1,5 +1,6 @@
 from .Base import Base
 from .ErrorMs import ErrorMs
+from .HttpResponse import HttpResponse
 
 
 class Worker(Base):
@@ -26,4 +27,9 @@ class Worker(Base):
             return self.formatResponse(request, RESP)
         except ErrorMs as err:
             # Retornar el error
-            return self.formatResponse(request, None, err.errorCode)
+            return self.formatResponse(
+                request,
+                # Generar formato
+                HttpResponse(None, err.http_code, headers=err.headers),
+                err.errorCode
+            )
