@@ -513,7 +513,8 @@ class Microservices(BaseClass, ABC):
         HTTP = None
 
         # Respuesta del servicio
-        RESPONSE_DATA = data["response"]["data"]["response"]
+        RESPONSE_DATA = None if data.get('response', None) is None else \
+            data["response"]["data"]["response"]
 
         # Validar si data no es de tipo httpResponse
         if (isinstance(RESPONSE_DATA, HttpResponse)):
